@@ -12,7 +12,6 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 import binascii
-import six
 import struct
 
 from geomet.util import block_splitter
@@ -116,7 +115,7 @@ def _get_geom_type(type_bytes):
         since this is big endian byte order), indicated as 0x20. If the SRID
         flag is not set, the high byte will always be null (0x00).
     :returns:
-        3-tuple ofGeoJSON geometry type label, the bytes resprenting the
+        3-tuple ofGeoJSON geometry type label, the bytes representing the
         geometry type, and a separate "has SRID" flag. If the input
         `type_bytes` contains an SRID flag, it will be removed.
 
@@ -132,9 +131,7 @@ def _get_geom_type(type_bytes):
 
     """
     # slice off the high byte, which may contain the SRID flag
-    high_byte = type_bytes[0]
-    if six.PY3:
-        high_byte = bytes([high_byte])
+    high_byte = bytes([type_bytes[0]])
     has_srid = high_byte == b'\x20'
     if has_srid:
         # replace the high byte with a null byte
@@ -213,22 +210,22 @@ def dumps(obj, big_endian=True):
         Defaults to `True`. If `True`, data values in the generated WKB will
         be represented using big endian byte order. Else, little endian.
 
-    TODO: remove this
-
-    :param str dims:
-        Indicates to WKB representation desired from converting the given
-        GeoJSON `dict` ``obj``. The accepted values are:
-
-        * '2D': 2-dimensional geometry (X, Y)
-        * 'Z': 3-dimensional geometry (X, Y, Z)
-        * 'M': 3-dimensional geometry (X, Y, M)
-        * 'ZM': 4-dimensional geometry (X, Y, Z, M)
-
     :returns:
         A WKB binary string representing of the ``obj``.
     """
+    return _dumps(obj, big_endian)
+
+
+def _dumps(obj, big_endian=True, include_meta=True):
+    """
+    Basically perform the action of dumps, but with some extra flags for
+    behavior specifically needed by the geopackage...package.
+    """
     geom_type = obj['type']
-    meta = obj.get('meta', {})
+    if include_meta:
+        meta = obj.get('meta', {})
+    else:
+        meta = {}
 
     exporter = _dumps_registry.get(geom_type)
     if exporter is None:
@@ -694,10 +691,7 @@ def _load_polygon(big_endian, type_bytes, data_bytes):
 
         verts_wkb = as_bin_str(take(8 * num_verts * num_dims, data_bytes))
         verts = block_splitter(verts_wkb, 8)
-        if six.PY2:
-            verts = (b''.join(x) for x in verts)
-        elif six.PY3:
-            verts = (b''.join(bytes([y]) for y in x) for x in verts)
+        verts = (b''.join(bytes([y]) for y in x) for x in verts)
         for vert_wkb in block_splitter(verts, num_dims):
             values = [struct.unpack('%sd' % endian_token, x)[0]
                       for x in vert_wkb]
@@ -922,7 +916,7 @@ def _load_geometrycollection(big_endian, type_bytes, data_bytes):
 
 
 _dumps_registry = {
-    'Point':  _dump_point,
+    'Point': _dump_point,
     'LineString': _dump_linestring,
     'Polygon': _dump_polygon,
     'MultiPoint': _dump_multipoint,
